Supported sensors — PolSARtools 0.9 documentation

Skip to main content
`Ctrl`+`K`

# Supported sensors

PolSARtools currently supports the import of sensor data from the following sources into polarimetric matrices.

- 🔸UAVSAR
  - GRD (`uavsar_grd`)
  - MLC (`uavsar_mlc`)
- 🔸ISRO ASAR
  - RSLC (`isro_asar`)
- 🔸ESAR
  - GTC SLC (`esar_gtc`)
- 🔸NISAR
  - RSLC (`nisar_rslc`)
  - GSLC (`nisar_gslc`)
- 🔸RISAT-1A
  - Level 1.1 (`risat_l11`)
- 🔸RADARSAT-2
  - Full-pol (`rs2_fp`)
- 🔸ALOS-2 PALSAR-2
  - FBD L1.1 (`alos2_fbd_l11`)
  - HBQ L1.1 (`alos2_hbq_l11`)
- 🔸Chandrayaan-II (DFSAR)
  - Full-pol (`chyaan2_fp`)